import { Alert } from 'react-native';
import Meteor, { Accounts } from 'react-native-meteor';
import moment from 'moment';
import { NavigationActions } from 'react-navigation';
import _ from 'lodash';
import OneSignal from 'react-native-onesignal';

export default class Utils {
  static alert = (content, onConfirm = () => {}) => {
    Alert.alert(null, content, [{ text: '확인', onPress: onConfirm }]);
  };

  static confirm = (content, onConfirm = () => {}, onCancel = () => {}) => {
    Alert.alert(null, content, [{ text: '취소', onPress: onCancel }, { text: '확인', onPress: onConfirm }]);
  };

  static getFormattedPrice = (amount, unit = '원') => {
    return parseInt(amount).toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',') + unit;
  };

  static getFormattedDate = (date) => {
    if (moment().diff(moment(date), 'days') < 5) {
      return moment(date).fromNow();
    }
    else {
      return moment(date).format('YYYY-MM-DD HH:mm');
    }
  };

  static getAge = (birthYear) => {
    return (moment().year() - birthYear + 1).toString();
  };

  static createUser = (options, callback) => {
    Accounts.createUser(options, (error) => {
      if (error) {
        if (error.reason == 'Email already exists.') {
          error.reason = '이미 존재하는 이메일입니다.';
        }
      }

      callback(error);
    });
  };

  static signIn = (email, password, callback) => {
    Meteor.loginWithPassword(email, password, async (error) => {
      if (error) {
        if (error.reason == 'User not found') {
          error.reason = '존재하지 않는 이메일입니다.';
        }
        else if (error.reason == 'Incorrect password') {
          error.reason = '비밀번호가 틀립니다.';
        }

        callback(error);

        return;
      }

      OneSignal.sendTag('id', Meteor.userId());

      callback();
    });
  };

  static reset = (to, navigation, params = {}) => {
    const resetAction = NavigationActions.reset({
      index: 0,
      actions: [
        NavigationActions.navigate({
          routeName: to,
          params: params
        })
      ]
    });

    navigation.dispatch(resetAction);
  };

  static signOut = (callback) => {
    OneSignal.sendTag('id', '');

    Meteor.logout(callback);
  };

  static deleteAccount = (keyWillBeUpdated = {}, callback) => {
    OneSignal.sendTag('id', '');

    const modifier = {
      'profile.isDeleted': true,
      'emails.0.address': `${Meteor.user().profile.email}_deleted`,
      'profile.email': `${Meteor.user().profile.email}_deleted`
    };

    _.extend(modifier, keyWillBeUpdated);

    Meteor.users.update({
      _id: Meteor.userId()
    }, {
      $set: modifier
    }, callback);
  };
}
